# Current Population Survey March Supplement

The Census Bureau administers the Current Population Survey March Supplement, also known as the Annual Social and Economic Supplement (ASEC). The March survey asks respondents about their economic circumstances over the prior calendar year. This is the core of the FiscalSim US enhanced dataset.

* [Microdata page](https://www.census.gov/data/datasets/time-series/demo/cps/cps-asec.html)
* [Latest codebook](https://www2.census.gov/programs-surveys/cps/datasets/2021/march/asec2021_ddl_pub_full.pdf)
